@@ -1,7 +1,7 @@
 
 use crate::utils::{
     cal3BV, cal3BV_exp, cal_table_minenum_enum, cal_table_minenum_recursion, combine, enuOneStep,
-    enum_comb, lay_mine_op_number, lay_mine_number, legalize_board, refreshBoard, refresh_matrix,
+    enum_comb, laymine_op_number, laymine_number, legalize_board, refreshBoard, refresh_matrix,
     refresh_matrixs, sum, unsolvable_structure, BigNumber, C_query, C,
 };
 
@@ -420,7 +420,7 @@ pub fn laymine_op(
     let mut Num3BV = 0;
     let mut Board = vec![vec![0; column]; row];
     while times < MaxTimes {
-        Board = lay_mine_op_number(row, column, MineNum, x0, y0);
+        Board = laymine_op_number(row, column, MineNum, x0, y0);
         times += 1;
         let mut Num3BV = cal3BV(&Board);
         if Num3BV >= Min3BV && Num3BV <= Max3BV {
@@ -592,7 +592,7 @@ pub fn laymine_solvable_thread(
                         break;
                     }
                 } // 这块用花括号控制生命周期
-                let Board_ = lay_mine_op_number(row, column, MineNum, x0, y0);
+                let Board_ = laymine_op_number(row, column, MineNum, x0, y0);
                 counter += 1;
                 if is_solvable(&Board_, x0, y0, enuLimit) {
                     Num3BV = cal3BV(&Board_);
@@ -612,7 +612,7 @@ pub fn laymine_solvable_thread(
                     }
                 }
             }
-            let Board_ = lay_mine_op_number(row, column, MineNum, x0, y0);
+            let Board_ = laymine_op_number(row, column, MineNum, x0, y0);
             Num3BV = cal3BV(&Board_);
             para[0] = 0;
             para[1] = Num3BV;
@@ -655,7 +655,7 @@ pub fn laymine_solvable(
     let mut Board;
     let mut Num3BV;
     while times < MaxTimes {
-        Board = lay_mine_op_number(row, column, MineNum, x0, y0);
+        Board = laymine_op_number(row, column, MineNum, x0, y0);
         times += 1;
         if is_solvable(&Board, x0, y0, enuLimit) {
             Num3BV = cal3BV(&Board);
@@ -667,7 +667,7 @@ pub fn laymine_solvable(
             }
         }
     }
-    Board = lay_mine_op_number(row, column, MineNum, x0, y0);
+    Board = laymine_op_number(row, column, MineNum, x0, y0);
     Num3BV = cal3BV(&Board);
     Parameters.push(0);
     Parameters.push(Num3BV);
@@ -676,7 +676,7 @@ pub fn laymine_solvable(
 }
 
 /// 调整法无猜埋雷（没写好）
-pub fn lay_mine_solvable_adjust(
+pub fn laymine_solvable_adjust(
     row: usize,
     column: usize,
     mine_num: usize,
@@ -735,7 +735,7 @@ pub fn laymine(
     let mut Num3BV = 0;
     let mut Board = vec![vec![0; column]; row];
     while times < MaxTimes {
-        Board = lay_mine_number(row, column, MineNum, x0, y0);
+        Board = laymine_number(row, column, MineNum, x0, y0);
         times += 1;
         Num3BV = cal3BV(&Board);
         if Num3BV >= Min3BV && Num3BV <= Max3BV {
@@ -759,7 +759,7 @@ pub fn sample_3BVs_exp(x0: usize, y0: usize, n: usize) -> [usize; 382] {
     let mut threads = vec![];
     for i in 0..16 {
         let join_item =
-            thread::spawn(move || -> [usize; 382] { lay_mine_number_study_exp(x0, y0, n0) });
+            thread::spawn(move || -> [usize; 382] { laymine_number_study_exp(x0, y0, n0) });
         threads.push(join_item);
     }
     let mut aa = [0; 382];
@@ -772,7 +772,7 @@ pub fn sample_3BVs_exp(x0: usize, y0: usize, n: usize) -> [usize; 382] {
 }
 
 #[cfg(any(feature = "py", feature = "rs"))]
-fn lay_mine_number_study_exp(x0: usize, y0: usize, n: usize) -> [usize; 382] {
+fn laymine_number_study_exp(x0: usize, y0: usize, n: usize) -> [usize; 382] {
     // 专用埋雷并计算3BV引擎，用于研究
     let mut rng = thread_rng();
     // let area: usize = 16 * 30 - 1;
