@@ -274,7 +274,7 @@ impl js_shuffle for Vec<i32> {
 
 /// 通用标准埋雷引擎，起手位置非雷，其余位置的雷服从均匀分布  
 /// 输出为二维的局面，其中0代表空，1~8代表1~8，-1代表雷
-pub fn lay_mine_number(
+pub fn laymine_number(
     row: usize,
     column: usize,
     MineNum: usize,
@@ -326,7 +326,7 @@ pub fn lay_mine_number(
 
 /// 通用win7埋雷引擎，起手位置开空，其余位置的雷服从均匀分布  
 /// 输出为二维的局面，其中0代表空，1~8代表1~8，-1代表雷
-pub fn lay_mine_op_number(
+pub fn laymine_op_number(
     row: usize,
     column: usize,
     MineNum: usize,
